Index: content/public/browser/content_browser_client.h |
diff --git a/content/public/browser/content_browser_client.h b/content/public/browser/content_browser_client.h |
index af10346b14b42ac5bdff3fd5032e4bbf772b6171..d1b61fe7cb9a652b4c23c86b744af72023a77664 100644 |
--- a/content/public/browser/content_browser_client.h |
+++ b/content/public/browser/content_browser_client.h |
@@ -46,12 +46,12 @@ class ImageSkia; |
namespace net { |
class CookieOptions; |
+class CookieStore; |
class HttpNetworkSession; |
class NetLog; |
class SSLCertRequestInfo; |
class SSLInfo; |
class URLRequest; |
-class URLRequestContext; |
class URLRequestContextGetter; |
class X509Certificate; |
} |
@@ -285,12 +285,12 @@ class CONTENT_EXPORT ContentBrowserClient { |
ResourceContext* context, |
const std::vector<std::pair<int, int> >& render_views); |
// Allow the embedder to override the request context based on the URL for |
// certain operations, like cookie access. Returns NULL to indicate the |
// regular request context should be used. |
// This is called on the IO thread. |
- virtual net::URLRequestContext* OverrideRequestContextForURL( |
- const GURL& url, ResourceContext* context); |
+ virtual net::CookieStore* OverrideCookieStoreForURL( |
+ const GURL& url, |
+ content::ResourceContext* context); |
// Allow the embedder to specify a string version of the storage partition |
// config with a site. |
@@ -285,12 +285,12 @@ class CONTENT_EXPORT ContentBrowserClient { |
ResourceContext* context, |
const std::vector<std::pair<int, int> >& render_views); |
- // Allow the embedder to override the request context based on the URL for |
- // certain operations, like cookie access. Returns NULL to indicate the |
- // regular request context should be used. |
+ // Allow the embedder to override the cookie store based on the URL. |
+ // Returns NULL to indicate the regular cookie store should be used. |
// This is called on the IO thread. |